import React, { useState, useRef, useEffect } from "react";
import iconUser from "../../public/iconUser.png";
import { useUser } from "../../hooks/useUser/useUser.jsx";
import { useEasyauth } from "../../hooks/useEasyauth/useEasyauth.jsx";

export const UserButton = () => {
  const auth = useEasyauth();
  const { user } = useUser();
  const [isOpen, setIsOpen] = useState(false);
  const cardRef = useRef(null);

  const handleButtonClick = () => {
    setIsOpen(!isOpen);
  };

  const handleLogout = () => {
    auth.removeUser();
  };

  const handleAccount = () => {
    // Redirect to account page
  };

  useEffect(() => {
    function handleClickOutside(event) {
      if (cardRef.current && !cardRef.current.contains(event.target)) {
        setIsOpen(false);
      }
    }

    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, []);

  

  return (
    <div style={{ position: "relative", display: "inline-block" }}>
      <button
        style={{
          width: "40px",
          height: "40px",
          borderRadius: "50%",
          padding: "0",
          border: "none",
          backgroundColor: "#ccc",
        }}
        onClick={handleButtonClick}
      >
        <img
          src={iconUser}
          alt="Profile Icon"
          style={{ width: "100%", height: "100%" }}
        />
      </button>

      {isOpen && (
        <div
          ref={cardRef}
          style={{
            position: "absolute",
            top: "50px",
            right: "0",
            width: "150px",
            borderRadius: "8px",
            backgroundColor: "#fff",
            boxShadow: "0 2px 4px rgba(0, 0, 0, 0.1)",
            padding: "10px",
            display: "flex",
            flexDirection: "column",
          }}
        >
          <div
            style={{
              display: "flex",
              alignItems: "center",
              marginBottom: "10px",
              overflow: "hidden",
              textOverflow: "ellipsis", 
            }}
          >
            <img
              src={iconUser}
              alt="Profile Icon"
              style={{ width: "30px", height: "30px", marginRight: "10px" }}
            />
            <div
              style={{
                color: "black",
                fontSize: "16px",
                overflow: "hidden",
                textOverflow: "ellipsis",
              }}
            >
              {user.email}
            </div>
          </div>
          <button
            style={{
              backgroundColor: "#007bff",
              color: "#fff",
              padding: "5px 10px",
              marginBottom: "10px",
              border: "none",
              borderRadius: "3px",
              cursor: "pointer",
            }}
            onClick={handleLogout}
          >
            Logout
          </button>
          <button
            style={{
              backgroundColor: "#17a2b8",
              color: "#fff",
              padding: "5px 10px",
              border: "none",
              borderRadius: "3px",
              cursor: "pointer",
            }}
            onClick={handleAccount}
          >
            Account
          </button>
        </div>
      )}
    </div>
  );
};
